#include "usart.h"

#include <avr/io.h>
#include <util/delay.h>

/* Functie ce seteaza pinii de intrare/iesire */
void ports_init(void)
{
	/* Setez pinii de iesire. */
	DDRD |= (1 << PD7);
	DDRD |= (1 << PD4);
	DDRD |= (1 << PD5);
	DDRB |= (1 << PB0);
	DDRB |= (1 << PB1);
	DDRB |= (1 << PB2);
	DDRB |= (1 << PB3);
	
	/* Setez pinul de receptie RX activ pentru receptie */
	DDRD &= ~(1 << PD0);
	PORTD |= (1 << PD0);
	
	/* Initializez pinii de iesire */
	PORTD |= (0 << PD7);
	PORTD |= (1 << PD4);
	PORTD |= (1 << PD5);
	PORTB |= (0 << PB0);
	PORTB |= (0 << PB1);
	PORTB |= (0 << PB2);
	PORTB |= (0 << PB3);
}

/* Functie ce initializeaza timer-ul */
void timer_init(void)
{
	/* Fast PWM mode, non-inverted mode, TOP OXFF and set on bottom */
	TCCR1A = (1 << WGM10) | (1 << COM1A1) | (1 << COM1B1);
    TCCR1B = (1 << CS10) | (1 << CS12) | (1 << WGM12);
	
	/* Very slow speed */
    OCR1A = 80;
	OCR1B = 80;
}

/* Functie ce trateaza input-ul de la aplicatia android */
void run()
{		
	char recv;
	static uint8_t power = 80;
	
	while(1){
		/* Se pirmeste input de la aplicatia android */
		recv = USART0_receive();
		/* Fata */
		if(recv == 'w'){			
			PORTD |= (1 << PD7);
			PORTB &= ~(1 << PB0);
			PORTB &= ~(1 << PB3);
			PORTB |= (1 << PB1);
			PORTB |= (1 << PB2);
		/* Spate */
		} else if(recv == 's'){
			PORTD |= (1 << PD7);
			PORTB &= ~(1 << PB1);
			PORTB &= ~(1 << PB2);
			PORTB |= (1 << PB0);
			PORTB |= (1 << PB3);
		/* Stanga */
		} else if(recv == 'a'){
			PORTD |= (1 << PD7);
			PORTB &= ~(1 << PB0);
			PORTB &= ~(1 << PB2);
			PORTB &= ~(1 << PB3);
			PORTB |= (1 << PB1);
		/* Dreapta */
		} else if(recv == 'd'){
			PORTD |= (1 << PD7);
			PORTB &= ~(1 << PB0);
			PORTB &= ~(1 << PB1);
			PORTB &= ~(1 << PB3);
			PORTB |= (1 << PB2);
		/* Viteza mica */
		} else if(recv == 'o'){
			power = 80;
		/* Viteza medie */
		} else if(recv == 'p'){
			power = 130;
		/* Viteza mare */
		} else if(recv == 'k'){
			power = 180;
		/* Viteza maxima */
		} else if(recv == 'l'){
			power = 255;
		/* Stop */
		} else {
			PORTB &= ~(1 << PD7);
			PORTB &= ~(1 << PB0);
			PORTB &= ~(1 << PB1);
			PORTB &= ~(1 << PB2);
			PORTB &= ~(1 << PB3);
		}
		OCR1A = power;
		OCR1B = power;
	}
}

int main()
{
    USART0_init();
	ports_init();
	timer_init();
	run(); 
    return 0;
}

